#               "new"       |       "old"
#         5   4   3   2   1   1   2   3   4   5
# Lure   24  20  14  12  10   8   6   3   2   1   100
# Target  1   2   3   5   4   9  12  15  20  29   100

import numpy as np
import matplotlib.pyplot as plt
import matplotlib
matplotlib.rcParams['pdf.fonttype'] = 42
matplotlib.rcParams['ps.fonttype'] = 42

responses = {'lures': {'new': np.array([24., 20., 14., 12., 10.]),
                       'old': np.array([8., 6., 3., 2., 1])},
             'targets': {'new': np.array([1., 2., 3., 5., 4.]),
                         'old': np.array([9., 12., 15., 20., 29])}}

responses_oldnewnorm = {}
responses_allnorm = {}
for targlure in responses:
    responses_oldnewnorm[targlure] = {}
    responses_allnorm[targlure] = {}
    for oldnew in responses[targlure]:
        responses_oldnewnorm[targlure][oldnew] = responses[targlure][
            oldnew] / responses[targlure][oldnew].sum()
        responses_allnorm[targlure][oldnew] = responses[targlure][
            oldnew] / (responses[targlure]['old'].sum() +
                       responses[targlure]['new'].sum())


roc_unnormalized = {'FAs': np.r_[0, responses['lures']['new'],
                                 responses['lures']['old']],
                    'HITs': np.r_[0, responses['targets']['new'],
                                  responses['targets']['old']]}
roc = {}
for key in roc_unnormalized:
    resp_sum = roc_unnormalized[key].sum()
    roc_unnormalized[key] = resp_sum-np.cumsum(
        roc_unnormalized[key])
    roc[key] = roc_unnormalized[key] / resp_sum

fig = plt.figure(figsize=(3, 3))
ax = plt.subplot(111, aspect='equal')
ax.plot(roc['FAs'][5:], roc['HITs'][5:], 'r-', linewidth=2., label='"old"')
ax.plot(roc['FAs'][6:], roc['HITs'][6:], 'r^')
ax.plot(roc['FAs'][:6], roc['HITs'][:6], 'g--', linewidth=2., label='"new"')
ax.plot(roc['FAs'][:5], roc['HITs'][:5], 'gv')
ax.plot(roc['FAs'][5], roc['HITs'][5], 'bD')
ax.plot([0, 1], [0, 1], 'k:', linewidth=2)
ax.plot([0, roc['FAs'][5], 1], [0, roc['HITs'][5], 1], 'k:', linewidth=2)
ax.legend(loc='lower right', frameon=False)
ax.set_xlabel('$p($FA$)$')
ax.set_ylabel('$p($HIT$)$')
ax.set_xlim((0, 1))
ax.set_ylim((0, 1))
fig.subplots_adjust(left=0.1, bottom=0.17, right=0.999, top=0.97)


cond_roc_unnormalized = {
    'old': {'FAs': np.r_[0, responses['lures']['old']],
            'HITs': np.r_[0, responses['targets']['old']]},
    'new': {'FAs': np.r_[0, responses['lures']['new']],
            'HITs': np.r_[0, responses['targets']['new']]}}

cond_roc = {}
for oldnew in cond_roc_unnormalized:
    cond_roc[oldnew] = {}
    for hitfa in cond_roc_unnormalized[oldnew]:
        resp_sum = cond_roc_unnormalized[oldnew][hitfa].sum()
        cond_roc_unnormalized[oldnew][hitfa] = resp_sum - (
            np.cumsum(cond_roc_unnormalized[oldnew][hitfa]))
        cond_roc[oldnew][hitfa] = cond_roc_unnormalized[oldnew][
            hitfa] / resp_sum

plt.figure()
plt.plot(cond_roc['old']['FAs'], cond_roc['old']['HITs'], 'ro-')
plt.plot(cond_roc['new']['FAs'], cond_roc['new']['HITs'], 'go--')



fig = plt.figure(figsize=(6, 2.9))
ax1 = plt.subplot(121, aspect='equal')
ax1.plot(roc['FAs'][5:], roc['HITs'][5:], 'r-', linewidth=2., label='"old"')
ax1.plot(roc['FAs'][6:], roc['HITs'][6:], 'r^')
ax1.plot(roc['FAs'][:6], roc['HITs'][:6], 'g--', linewidth=2., label='"new"')
ax1.plot(roc['FAs'][:5], roc['HITs'][:5], 'gv')
ax1.plot(roc['FAs'][5], roc['HITs'][5], 'bD')
ax1.plot([0, 1], [0, 1], 'k:', linewidth=2)
ax1.plot([0, roc['FAs'][5], 1], [0, roc['HITs'][5], 1], 'k:', linewidth=2)
ax1.legend(loc='lower right', frameon=False)
ax1.set_xlabel('$p($FA$)$')
ax1.set_ylabel('$p($HIT$)$')
ax1.set_xlim((0, 1))
ax1.set_ylim((0, 1))
ax2 = plt.subplot(122, aspect='equal')
ax2.plot(cond_roc['old']['FAs'], cond_roc['old']['HITs'],
         'r-', linewidth=2., label='"old"')
ax2.plot(cond_roc['new']['FAs'], cond_roc['new']['HITs'],
         'g--', linewidth=2., label='"new"')
ax2.plot(cond_roc['old']['FAs'], cond_roc['old']['HITs'], 'r^', linewidth=2.)
ax2.plot(cond_roc['new']['FAs'], cond_roc['new']['HITs'], 'gv', linewidth=2.)
ax2.plot([0, 1], [0, 1], 'k:', linewidth=2)
ax2.legend(loc='lower right', frameon=False)
ax2.set_xlabel('$p($FA$)$')
ax2.set_ylabel('$p($HIT$)$')
ax2.set_xlim((0, 1))
ax2.set_ylim((0, 1))
fig.subplots_adjust(left=0.08, bottom=0.17, right=0.99, top=0.97, hspace=0.2)
plt.savefig('./figs/roc_tutorial.pdf')
